@@ -342,7 +342,6 @@ const Application = new Lang.Class({
         trackerController = new TrackerController.TrackerController();
         selectionController = new Selections.SelectionController();
         modeController = new WindowMode.ModeController();
-        notificationManager = new Notifications.NotificationManager();
 
         this._actionEntries = [
             { name: 'quit',
@@ -372,6 +371,10 @@ const Application = new Lang.Class({
             { name: 'open-current',
               callback: this._onActionOpenCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'edit-current',
+              window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'view-current',
+              window_mode: WindowMode.WindowMode.EDIT },
             { name: 'print-current', accel: '<Primary>p',
               callback: this._onActionPrintCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
@@ -400,8 +403,13 @@ const Application = new Lang.Class({
             { name: 'properties',
               callback: this._onActionProperties,
               window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'bookmark-page',
+              callback: this._onActionToggle,
+              state: GLib.Variant.new('b', false),
+              accel: '<Primary>d',
+              window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'places',
-              accel: 'F3',
+              accel: '<Primary>b',
               window_mode: WindowMode.WindowMode.PREVIEW }
         ];
 
