@@ -918,16 +918,44 @@ const DocumentManager = new Lang.Class({
         this.parent();
     },
 
+    _humanizeError: function(error) {
+        let message = error.message;
+        if (error.domain == GData.ServiceError) {
+            switch (error.code) {
+            case GData.ServiceError.NETWORK_ERROR:
+                message = _("Please check the network connection.");
+                break;
+            case GData.ServiceError.PROXY_ERROR:
+                message = _("Please check the network proxy settings.");
+                break;
+            case GData.ServiceError.AUTHENTICATION_REQUIRED:
+                message = _("Unable to sign in to the document service.");
+                break;
+            case GData.ServiceError.NOT_FOUND:
+                message = _("Unable to locate this document.");
+                break;
+            default:
+                message = _("Hmm, something is fishy (%d).").format(error.code);
+                break;
+            }
+        }
+        let exception = new GLib.Error(error.domain, error.code, message);
+        return exception;
+    },
+
     _onDocumentLoadError: function(doc, error) {
         if (error.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED))
             return;
 
         // Translators: %s is the title of a document
-        let message = _("Unable to load \"%s\" for preview").format(doc.name);
-        this.emit('load-error', doc, message, error);
+        let message = _("Oops! Unable to load “%s”").format(doc.name);
+        let exception = this._humanizeError(error);
+        this.emit('load-error', doc, message, exception);
     },
 
     _onDocumentLoaded: function(doc, docModel, error) {
+        this._loaderCancellable = null;
+
         if (error) {
             this._onDocumentLoadError(doc, error);
             return;
@@ -936,10 +964,28 @@ const DocumentManager = new Lang.Class({
         // save loaded model and signal
         this._activeDocModel = docModel;
         this._activeDocModel.set_continuous(false);
-        this.emit('load-finished', doc, docModel);
 
         // load metadata
         this._connectMetadata(docModel);
+
+        this.emit('load-finished', doc, docModel);
+    },
+
+    reloadActiveItem: function() {
+        let doc = this.getActiveItem();
+
+        if (!doc)
+            return;
+
+        if (doc.collection)
+            return;
+
+        // cleanup any state we have for previously loaded model
+        this._clearActiveDocModel();
+
+        this._loaderCancellable = new Gio.Cancellable();
+        doc.load(this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
+        this.emit('load-started', doc);
     },
 
     setActiveItem: function(doc) {
@@ -985,6 +1031,7 @@ const DocumentManager = new Lang.Class({
                     this._activeDocModel.disconnect(id);
                 }));
 
+            this.metadata = null;
             this._activeDocModel = null;
             this._activeDocModelIds = [];
         }
@@ -993,20 +1040,19 @@ const DocumentManager = new Lang.Class({
     _connectMetadata: function(docModel) {
         let evDoc = docModel.get_document();
         let file = Gio.File.new_for_uri(evDoc.get_uri());
-
         if (!GdPrivate.is_metadata_supported_for_file(file))
             return;
 
-        let metadata = new GdPrivate.Metadata({ file: file });
+        this.metadata = new GdPrivate.Metadata({ file: file });
 
         // save current page in metadata
-        let [res, val] = metadata.get_int('page');
+        let [res, val] = this.metadata.get_int('page');
         if (res)
             docModel.set_page(val);
         this._activeDocModelIds.push(
             docModel.connect('page-changed', Lang.bind(this,
                 function(source, oldPage, newPage) {
-                    metadata.set_int('page', newPage);
+                    this.metadata.set_int('page', newPage);
                 }))
         );
     }
