@@ -30,13 +30,14 @@
 #include <evince-document.h>
 #include <evince-view.h>
 
+#include <libgd/gd.h>
+
 #include "gd-places-links.h"
 #include "gd-places-page.h"
 
 struct _GdPlacesLinksPrivate {
         GtkWidget *tree_view;
 
-        guint selection_id;
         guint page_changed_id;
         guint link_activated_id;
 
@@ -44,6 +45,13 @@ struct _GdPlacesLinksPrivate {
         GtkTreeModel *model;
         EvDocument *document;
         EvDocumentModel *document_model;
+        const char *name;
+};
+
+enum {
+        PROP_0,
+        PROP_NAME,
+        PROP_DOCUMENT_MODEL,
 };
 
 enum {
@@ -74,7 +82,6 @@ emit_link_activated (GdPlacesLinks *self)
         GtkTreeIter iter;
 
         selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (self->priv->tree_view));
-
         if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
                 EvLink *link;
                 EvDocumentModel *document_model;
@@ -109,15 +116,12 @@ emit_link_activated (GdPlacesLinks *self)
 }
 
 static void
-selection_changed_cb (GtkTreeSelection *selection,
-                      GdPlacesLinks    *self)
+schedule_emit_link_activated (GdPlacesLinks *self)
 {
-        g_return_if_fail (self->priv->document != NULL);
-
         /* jump through some hoops to avoid destroying in the middle
-           of a button press handler */
+           of a button release handler */
         if (self->priv->link_activated_id == 0) {
-                self->priv->link_activated_id = g_idle_add ((GSourceFunc)emit_link_activated, self);
+                self->priv->link_activated_id = g_idle_add ((GSourceFunc) emit_link_activated, self);
         }
 }
 
@@ -192,13 +196,9 @@ gd_places_links_set_current_page (GdPlacesLinks *self,
          * a GtkTreeModelSort here to make it faster, if it turns out to be
          * slow.
          */
-        g_signal_handler_block (selection, self->priv->selection_id);
-
         gtk_tree_model_foreach (model,
                                 (GtkTreeModelForeachFunc)update_page_cb_foreach,
                                 self);
-
-        g_signal_handler_unblock (selection, self->priv->selection_id);
 }
 
 static void
@@ -228,13 +228,6 @@ job_finished_cb (EvJobLinks     *job,
 
         gtk_tree_view_expand_all (GTK_TREE_VIEW (priv->tree_view));
 
-        if (priv->selection_id <= 0) {
-                priv->selection_id =
-                        g_signal_connect (selection, "changed",
-                                          G_CALLBACK (selection_changed_cb),
-                                          self);
-        }
-
         if (priv->page_changed_id <= 0) {
                 priv->page_changed_id =
                         g_signal_connect_swapped (priv->document_model, "page-changed",
@@ -287,6 +280,9 @@ gd_places_links_construct (GdPlacesLinks *self)
 
         /* Create tree view */
         priv->tree_view = gtk_tree_view_new ();
+        gtk_tree_view_set_activate_on_single_click (GTK_TREE_VIEW (priv->tree_view), TRUE);
+        g_signal_connect_swapped (priv->tree_view, "row-activated",
+                                  G_CALLBACK (schedule_emit_link_activated), self);
 
         gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (priv->tree_view), FALSE);
         gtk_tree_view_set_level_indentation (GTK_TREE_VIEW (priv->tree_view), 20);
@@ -314,15 +310,14 @@ gd_places_links_construct (GdPlacesLinks *self)
                                              "markup", EV_DOCUMENT_LINKS_COLUMN_MARKUP,
                                              NULL);
 
-        renderer = (GtkCellRenderer *)
-                g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
-                              "ellipsize", PANGO_ELLIPSIZE_MIDDLE,
-                              "foreground", "#cccccc",
-                              "max-width-chars", 12,
-                              "scale", PANGO_SCALE_SMALL,
-                              "xalign", 1.0,
-                              "xpad", 10,
-                              NULL);
+        renderer = gd_styled_text_renderer_new ();
+        gd_styled_text_renderer_add_class (GD_STYLED_TEXT_RENDERER (renderer), "dim-label");
+        g_object_set (renderer,
+                      "max-width-chars", 12,
+                      "scale", PANGO_SCALE_SMALL,
+                      "xalign", 1.0,
+                      "xpad", 10,
+                      NULL);
         gtk_tree_view_column_pack_end (GTK_TREE_VIEW_COLUMN (column), renderer, FALSE);
         gtk_tree_view_column_set_attributes (GTK_TREE_VIEW_COLUMN (column), renderer,
                                              "text", EV_DOCUMENT_LINKS_COLUMN_PAGE_LABEL,
@@ -397,30 +392,18 @@ gd_places_links_document_changed_cb (EvDocumentModel *model,
 }
 
 static gboolean
-gd_places_links_supports_document (GdPlacesPage *places_page,
+gd_places_links_supports_document (GdPlacesPage *page,
                                    EvDocument   *document)
 {
         return (EV_IS_DOCUMENT_LINKS (document) &&
                 ev_document_links_has_document_links (EV_DOCUMENT_LINKS (document)));
 }
 
-static const char *
-gd_places_links_get_label (GdPlacesPage *places_page)
-{
-        return _("Contents");
-}
-
-static const char *
-gd_places_links_get_icon_name (GdPlacesPage *places_page)
-{
-        return "view-list-symbolic";
-}
-
 static void
-gd_places_links_set_document_model (GdPlacesPage    *places_page,
+gd_places_links_set_document_model (GdPlacesPage    *page,
                                     EvDocumentModel *model)
 {
-        GdPlacesLinks *self = GD_PLACES_LINKS (places_page);
+        GdPlacesLinks *self = GD_PLACES_LINKS (page);
         GdPlacesLinksPrivate *priv = self->priv;
 
         if (priv->document_model == model) {
@@ -435,7 +418,7 @@ gd_places_links_set_document_model (GdPlacesPage    *places_page,
         if (priv->document_model != NULL) {
                 g_signal_handlers_disconnect_by_func (priv->document_model,
                                                       gd_places_links_document_changed_cb,
-                                                      places_page);
+                                                      page);
         }
 
         g_clear_object (&priv->document_model);
@@ -447,13 +430,19 @@ gd_places_links_set_document_model (GdPlacesPage    *places_page,
                 g_signal_connect (priv->document_model,
                                   "notify::document",
                                   G_CALLBACK (gd_places_links_document_changed_cb),
-                                  places_page);
+                                  page);
                 gd_places_links_document_changed_cb (priv->document_model,
                                                      NULL,
                                                      self);
         }
 }
 
+static const char *
+gd_places_links_get_name (GdPlacesPage *page)
+{
+        return GD_PLACES_LINKS (page)->priv->name;
+}
+
 static void
 gd_places_links_dispose (GObject *object)
 {
@@ -481,12 +470,53 @@ gd_places_links_dispose (GObject *object)
         G_OBJECT_CLASS (gd_places_links_parent_class)->dispose (object);
 }
 
+static void
+gd_places_links_set_property (GObject      *object,
+                              guint         prop_id,
+                              const GValue *value,
+                              GParamSpec   *pspec)
+{
+
+        GdPlacesLinks *self = GD_PLACES_LINKS (object);
+
+        switch (prop_id) {
+        case PROP_DOCUMENT_MODEL:
+                gd_places_links_set_document_model (GD_PLACES_PAGE (self), g_value_get_object (value));
+                break;
+        default:
+                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+                break;
+        }
+}
+
+static void
+gd_places_links_get_property (GObject    *object,
+                              guint       prop_id,
+                              GValue     *value,
+                              GParamSpec *pspec)
+{
+        GdPlacesLinks *self = GD_PLACES_LINKS (object);
+
+        switch (prop_id) {
+        case PROP_NAME:
+                g_value_set_string (value, self->priv->name);
+                break;
+        case PROP_DOCUMENT_MODEL:
+                g_value_set_object (value, self->priv->document_model);
+                break;
+        default:
+                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+                break;
+        }
+}
 
 static void
 gd_places_links_init (GdPlacesLinks *self)
 {
         self->priv = GD_PLACES_LINKS_GET_PRIVATE (self);
 
+        self->priv->name = _("Contents");
+
         gd_places_links_construct (self);
 }
 
@@ -495,7 +525,7 @@ gd_places_links_page_iface_init (GdPlacesPageInterface *iface)
 {
         iface->supports_document = gd_places_links_supports_document;
         iface->set_document_model = gd_places_links_set_document_model;
-        iface->get_label = gd_places_links_get_label;
+        iface->get_name = gd_places_links_get_name;
 }
 
 static void
@@ -504,6 +534,8 @@ gd_places_links_class_init (GdPlacesLinksClass *klass)
         GObjectClass *oclass = G_OBJECT_CLASS (klass);
 
         oclass->dispose = gd_places_links_dispose;
+        oclass->set_property = gd_places_links_set_property;
+        oclass->get_property = gd_places_links_get_property;
 
         signals[LINK_ACTIVATED] = g_signal_new ("link-activated",
                                                 G_TYPE_FROM_CLASS (oclass),
@@ -513,6 +545,9 @@ gd_places_links_class_init (GdPlacesLinksClass *klass)
                                                 g_cclosure_marshal_VOID__OBJECT,
                                                 G_TYPE_NONE, 1, G_TYPE_OBJECT);
 
+        g_object_class_override_property (oclass, PROP_NAME, "name");
+        g_object_class_override_property (oclass, PROP_DOCUMENT_MODEL, "document-model");
+
         g_type_class_add_private (oclass, sizeof (GdPlacesLinksPrivate));
 }
 
