@@ -34,11 +34,6 @@ gboolean gd_queue_thumbnail_job_for_file_finish (GAsyncResult *res);
 void gd_gtk_tree_view_set_activate_on_single_click (GtkTreeView *tree_view,
                                                     gboolean should_activate);
 
-GdkPixbuf *gd_embed_image_in_frame (GdkPixbuf *source_image,
-                                    const gchar *frame_image_path,
-                                    GtkBorder *slice_width,
-                                    GtkBorder *border_width);
-
 const char *gd_filename_get_extension_offset (const char *filename);
 
 char *gd_filename_strip_extension (const char * filename_with_extension);
