@@ -31,13 +31,15 @@ const Signals = imports.signals;
 const BaseManager = new Lang.Class({
     Name: 'BaseManager',
 
-    _init: function(title) {
+    _init: function(title, context) {
         this._items = {};
         this._activeItem = null;
         this._title = null;
 
         if (title)
             this._title = title;
+
+        this.context = context;
     },
 
     getTitle: function() {
@@ -54,6 +56,12 @@ const BaseManager = new Lang.Class({
     },
 
     addItem: function(item) {
+        item._manager = this;
+
+        let oldItem = this._items[item.id];
+        if (oldItem)
+            this.removeItem(oldItem);
+
         this._items[item.id] = item;
         this.emit('item-added', item);
     },
@@ -96,6 +104,7 @@ const BaseManager = new Lang.Class({
         if (item) {
             delete this._items[id];
             this.emit('item-removed', item);
+            item._manager = null;
         }
     },
 
