@@ -30,6 +30,7 @@ const _ = imports.gettext.gettext;
 
 const Application = imports.application;
 const Utils = imports.utils;
+const WindowMode = imports.windowMode;
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
@@ -85,7 +86,7 @@ const PrintNotification = new Lang.Class({
         let status = this._printOp.get_status();
         let fraction = this._printOp.get_progress();
 	let name = this._printOp.get_job_name();
-	status = _("Printing \"%s\": %s").format(this._doc.name, status);
+	status = _("Printing “%s”: %s").format(this._doc.name, status);
 
         this._statusLabel.set_text(status);
         this._progressBar.fraction = fraction;
@@ -115,14 +116,15 @@ const IndexingNotification = new Lang.Class({
         }
 
         Application.application.connectJS('miners-changed', Lang.bind(this, this._checkNotification));
-        Mainloop.idle_add(Lang.bind(this,
-            function() {
-                this._checkNotification();
-                return false;
-            }));
+        Application.modeController.connect('window-mode-changed', Lang.bind(this, this._checkNotification));
     },
 
     _checkNotification: function() {
+        if (Application.modeController.getWindowMode() == WindowMode.WindowMode.PREVIEW) {
+            this._destroy(false);
+            return;
+        }
+
         let isIndexingLocal = false;
         let isIndexingRemote = false;
 
@@ -154,9 +156,13 @@ const IndexingNotification = new Lang.Class({
         this._timeoutId = 0;
 
         let primary = null;
+        let miner = null;
 
         if (Application.application.minersRunning.length == 1) {
-            let miner = Application.application.minersRunning[0];
+            miner = Application.application.minersRunning[0];
+        }
+
+        if (miner && miner.DisplayName) {
             primary = _("Fetching documents from %s").format(miner.DisplayName);
         } else {
             primary = _("Fetching documents from online accounts");
