@@ -78,6 +78,10 @@ const PreviewView = new Lang.Class({
 
         this.widget.show_all();
 
+        Application.application.connect('action-state-changed::bookmark-page',
+            Lang.bind(this, this._onActionStateChanged));
+        this._onActionStateChanged(Application.application, 'bookmark-page', Application.application.get_action_state('bookmark-page'));
+
         this._zoomIn = Application.application.lookup_action('zoom-in');
         this._zoomIn.connect('activate', Lang.bind(this,
             function() {
@@ -115,10 +119,58 @@ const PreviewView = new Lang.Class({
             }));
         let showPlaces = Application.application.lookup_action('places');
         showPlaces.connect('activate', Lang.bind(this, this._showPlaces));
+
+        Application.documentManager.connect('load-started',
+                                            Lang.bind(this, this._onLoadStarted));
+        Application.documentManager.connect('load-finished',
+                                            Lang.bind(this, this._onLoadFinished));
+        Application.documentManager.connect('load-error',
+                                            Lang.bind(this, this._onLoadError));
+    },
+
+   _onLoadStarted: function() {
+        this._showPlaces.enabled = false;
+    },
+
+    _onLoadFinished: function(manager, doc, docModel) {
+        this._showPlaces.enabled = true;
+
+        if (!Application.documentManager.metadata)
+            return;
+
+        this._bookmarks = new GdPrivate.Bookmarks({ metadata: Application.documentManager.metadata });
+    },
+
+    _onLoadError: function(manager, doc, message, exception) {
+        this._controlsVisible = true;
+        this._syncControlsVisible();
+    },
+
+    _onActionStateChanged: function(source, actionName, state) {
+        if (!this._model)
+            return;
+
+        let page_number = this._model.page;
+        let bookmark = new GdPrivate.Bookmark({ page_number: page_number });
+
+        if (state.get_boolean())
+            this._bookmarks.add(bookmark);
+        else
+            this._bookmarks.remove(bookmark);
+    },
+
+    _onPageChanged: function() {
+        this._pageChanged = true;
+
+        let page_number = this._model.page;
+        let bookmark = new GdPrivate.Bookmark({ page_number: page_number });
+        let hasBookmark = (this._bookmarks.find_bookmark(bookmark) != null);
+
+        Application.application.change_action_state('bookmark-page', GLib.Variant.new('b', (hasBookmark)));
     },
 
     _showPlaces: function() {
-        let dialog = new Places.PlacesDialog(this._model);
+        let dialog = new Places.PlacesDialog(this._model, this._bookmarks);
         dialog.widget.connect('response', Lang.bind(this,
             function(widget, response) {
                 widget.destroy();
@@ -348,12 +400,8 @@ const PreviewView = new Lang.Class({
         if (this._model) {
             this._createView();
             this.view.set_model(this._model);
-            this._navBar.widget.document_model = model;
-            this._model.connect('page-changed', Lang.bind(this,
-                function() {
-                    this._pageChanged = true;
-                }));
-
+            this._navBar.setModel(model);
+            this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
         }
     },
 
@@ -371,10 +419,13 @@ const PreviewView = new Lang.Class({
 });
 Signals.addSignalMethods(PreviewView.prototype);
 
+const _PREVIEW_NAVBAR_MARGIN = 40;
+
 const PreviewNav = new Lang.Class({
     Name: 'PreviewNav',
 
     _init: function(model) {
+        this._model = model;
         this.widget = new GdPrivate.NavBar({ document_model: model });
         this.widget.get_style_context().add_class('osd');
 
@@ -383,18 +434,39 @@ const PreviewNav = new Lang.Class({
                                                              pixel_size: 16 }),
                                       valign: Gtk.Align.CENTER
                                     });
-        let button_area = this.widget.get_button_area();
-        button_area.pack_start(button, false, false, 0);
+        let buttonArea = this.widget.get_button_area();
+        buttonArea.pack_start(button, false, false, 0);
+
+        button = new Gtk.ToggleButton({ action_name: 'app.bookmark-page',
+                                        child: new Gtk.Image({ icon_name: 'bookmark-add-symbolic',
+                                                               pixel_size: 16 }),
+                                        valign: Gtk.Align.CENTER
+                                      });
+        buttonArea.pack_start(button, false, false, 0);
 
         this.actor = new GtkClutter.Actor({ contents: this.widget,
                                             visible: false,
+                                            margin_top: _PREVIEW_NAVBAR_MARGIN,
+                                            margin_bottom: _PREVIEW_NAVBAR_MARGIN,
+                                            margin_left: _PREVIEW_NAVBAR_MARGIN,
+                                            margin_right: _PREVIEW_NAVBAR_MARGIN,
                                             opacity: 0 });
         Utils.alphaGtkWidget(this.actor.get_widget());
 
         this.widget.show_all();
     },
 
+    setModel: function(model) {
+        this._model = model;
+        this.widget.document_model = model;
+        if (!model)
+            this.hide();
+    },
+
     show: function() {
+        if (!this._model)
+            return;
+
         this.actor.show();
 
         Tweener.addTween(this.actor,
